# Changelog

## 1.0.0

 - Initial release

## 1.0.1

 - Fix tox.ini deps
 - Add CHANGELOG.md 
 - Update the README.md
 
 ## 1.0.2
 
  - Update the README.md - Fix the module name
  
 ## 1.0.3
 
  - Fix the MANIFEST.in to include the tmplates and statics files  